km3modules.common.HitCounter
============================

.. currentmodule:: km3modules.common

.. autoclass:: HitCounter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HitCounter.__init__
      ~HitCounter.add
      ~HitCounter.configure
      ~HitCounter.expose
      ~HitCounter.finish
      ~HitCounter.get
      ~HitCounter.pre_finish
      ~HitCounter.process
      ~HitCounter.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HitCounter.name
   
   